@@ -3,7 +3,6 @@
 //! [Introduction to Interval Arithmetic][`_docs::intro`]
 
 #![feature(asm)]
-#![feature(external_doc)]
 #![cfg_attr(target_arch = "aarch64", feature(stdsimd))]
 #![allow(clippy::float_cmp)]
 
@@ -34,7 +33,7 @@ mod parse;
 mod set_op;
 
 cfg_if::cfg_if! {
-    if #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))] {
+    if #[cfg(any(target_arch = "aarch64", target_arch = "x86_64", docsrs))] {
         mod simd;
     } else {
         compile_error!("Only x86-64 and AArch64 (experimental) architectures are supported by this crate.");
